/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adsense.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for AdStyle.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the AdSense Management API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class AdStyle extends GenericJson {

  /**
   * The colors which are included in the style. These are represented as six hexadecimal
   * characters, similar to HTML color codes, but without the leading hash.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Colors colors;

  /**
   * The style of the corners in the ad.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String corners;

  /**
   * The font which is included in the style.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Font font;

  /**
   * Kind this is, in this case adsense#adStyle.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The colors which are included in the style. These are represented as six hexadecimal
   * characters, similar to HTML color codes, but without the leading hash.
   * The value returned may be {@code null}.
   */
  public Colors getColors() {
    return colors;
  }

  /**
   * The colors which are included in the style. These are represented as six hexadecimal
   * characters, similar to HTML color codes, but without the leading hash.
   * The value set may be {@code null}.
   */
  public AdStyle setColors(Colors colors) {
    this.colors = colors;
    return this;
  }

  /**
   * The style of the corners in the ad.
   * The value returned may be {@code null}.
   */
  public String getCorners() {
    return corners;
  }

  /**
   * The style of the corners in the ad.
   * The value set may be {@code null}.
   */
  public AdStyle setCorners(String corners) {
    this.corners = corners;
    return this;
  }

  /**
   * The font which is included in the style.
   * The value returned may be {@code null}.
   */
  public Font getFont() {
    return font;
  }

  /**
   * The font which is included in the style.
   * The value set may be {@code null}.
   */
  public AdStyle setFont(Font font) {
    this.font = font;
    return this;
  }

  /**
   * Kind this is, in this case adsense#adStyle.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Kind this is, in this case adsense#adStyle.
   * The value set may be {@code null}.
   */
  public AdStyle setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The colors which are included in the style. These are represented as six hexadecimal characters,
   * similar to HTML color codes, but without the leading hash.
   */
  public static final class Colors extends GenericJson {

    /**
     * The color of the ad background.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String background;

    /**
     * The color of the ad border.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String border;

    /**
     * The color of the ad text.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String text;

    /**
     * The color of the ad title.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String title;

    /**
     * The color of the ad url.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String url;

    /**
     * The color of the ad background.
     * The value returned may be {@code null}.
     */
    public String getBackground() {
      return background;
    }

    /**
     * The color of the ad background.
     * The value set may be {@code null}.
     */
    public Colors setBackground(String background) {
      this.background = background;
      return this;
    }

    /**
     * The color of the ad border.
     * The value returned may be {@code null}.
     */
    public String getBorder() {
      return border;
    }

    /**
     * The color of the ad border.
     * The value set may be {@code null}.
     */
    public Colors setBorder(String border) {
      this.border = border;
      return this;
    }

    /**
     * The color of the ad text.
     * The value returned may be {@code null}.
     */
    public String getText() {
      return text;
    }

    /**
     * The color of the ad text.
     * The value set may be {@code null}.
     */
    public Colors setText(String text) {
      this.text = text;
      return this;
    }

    /**
     * The color of the ad title.
     * The value returned may be {@code null}.
     */
    public String getTitle() {
      return title;
    }

    /**
     * The color of the ad title.
     * The value set may be {@code null}.
     */
    public Colors setTitle(String title) {
      this.title = title;
      return this;
    }

    /**
     * The color of the ad url.
     * The value returned may be {@code null}.
     */
    public String getUrl() {
      return url;
    }

    /**
     * The color of the ad url.
     * The value set may be {@code null}.
     */
    public Colors setUrl(String url) {
      this.url = url;
      return this;
    }

  }

  /**
   * The font which is included in the style.
   */
  public static final class Font extends GenericJson {

    /**
     * The family of the font.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String family;

    /**
     * The size of the font.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String size;

    /**
     * The family of the font.
     * The value returned may be {@code null}.
     */
    public String getFamily() {
      return family;
    }

    /**
     * The family of the font.
     * The value set may be {@code null}.
     */
    public Font setFamily(String family) {
      this.family = family;
      return this;
    }

    /**
     * The size of the font.
     * The value returned may be {@code null}.
     */
    public String getSize() {
      return size;
    }

    /**
     * The size of the font.
     * The value set may be {@code null}.
     */
    public Font setSize(String size) {
      this.size = size;
      return this;
    }

  }

}
